@@ -50,7 +50,7 @@ def apache_conf_path():
         abort('Load beanstalk settings first')
 
     beanstalk_stack_base = beanstalk_settings['BEANSTALK_STACK_BASE']
-    return os.path.join(beanstalk_stack_base, 'apache.conf')
+    return os.path.join(beanstalk_stack_base, 'confs/', 'apache.conf')
 
 
 def apps_pool_path():
@@ -165,6 +165,7 @@ def setup(settings_path=None, **settings_patches):
     local('mkdir -p %s' % beanstalk_stack_base)
     local('mkdir -p %s' % os.path.join(beanstalk_stack_base, 'global-logs'))
     local('mkdir -p %s' % os.path.join(beanstalk_stack_base, 'apps'))
+    local('mkdir -p %s' % os.path.join(beanstalk_stack_base, 'confs'))
     local('echo "{}" >> %s' % apps_pool_path())
     local('chmod o+rx %s' % beanstalk_stack_base)
     local('chown -R beanstalk:beanstalk %s' % beanstalk_stack_base)
